##  Fact Sheets
**Note**
For events related to fact sheets, you can optionally select a fact sheet type. This allows you to receive event notifications only for this fact sheet type without configuring a callback.
Event | Description
---|---
FACT_SHEET_CREATED | A new fact sheet is created.
FACT_SHEET_UPDATED | A fact sheet is updated. This also includes updates to fact sheet relations.
FACT_SHEET_VIEWED | A fact sheet is viewed by a workspace user.
FACT_SHEET_ARCHIVED | A fact sheet is archived.
FACT_SHEET_DELETED | A fact sheet is deleted. Deletion occurs when a fact sheet type is deleted from the meta model configuration or the retention period for an archived fact sheet ends.
FACT_SHEET_RECOVERED | A fact sheet is recovered.


